pub struct CompileConfig {
pub temp_file: PathBuf,
pub output_dir: PathBuf,
pub extra_args: Vec<String>,
pub completed_notes_metadata: Vec<CompletedNote>,
pub required_formats: Vec<Format>,
}Expand description
Configuration for compiling Typst files.
Fields
temp_file: PathBufThe temporary Typst file to compile.
output_dir: PathBufOutput directory for compiled files.
extra_args: Vec<String>Additional arguments to pass to typst compile.
completed_notes_metadata: Vec<CompletedNote>Note metadata with all defaults applied, in document order.
required_formats: Vec<Format>The image formats that must be compiled for this run.
Implementations
Sourceimpl CompileConfig
impl CompileConfig